@@ -5,18 +5,18 @@ mod storage_iter;
 mod use_local_storage;
 mod use_session_storage;
 
-pub use self::{builder::UseStorageBuilder, use_local_storage::UseLocalStorage};
+use self::storage_iter::{on_storage, UseStorageData};
+pub use self::{builder::UseStorageBuilder, storage_iter::StorageIter, use_local_storage::UseLocalStorage};
 use crate::hooks::use_session_storage::UseSessionStorage;
 use dioxus::core::ScopeState;
 use gloo_events::EventListener;
-use log::info;
+use log::{info, warn};
 use std::{
     cell::RefCell,
     fmt::{Debug, Display, Formatter},
     marker::PhantomData,
     rc::Rc,
 };
-use storage_iter::storage_eq;
 use wasm_bindgen::JsCast;
 use web_sys::{window, Storage, StorageEvent, Window};
 
@@ -36,7 +36,7 @@ use web_sys::{window, Storage, StorageEvent, Window};
 ///     let hook = use_local_storage(&cx);
 ///
 ///     cx.render(rsx!(
-///         h1 { "Local Storage: {hook}" }
+///         h1 { "Local Storage: {hook:#?}" }
 ///     ))
 /// }
 /// ```
@@ -69,19 +69,3 @@ pub fn use_local_storage(cx: &ScopeState) -> &UseLocalStorage {
 pub fn use_session_storage(cx: &ScopeState) -> &UseSessionStorage {
     UseStorageBuilder::default().use_session_storage(cx)
 }
-
-#[allow(dead_code)]
-struct UseStorageData {
-    storage: Option<Storage>,
-    last_event: Option<StorageEvent>,
-}
-
-///
-#[derive(Debug)]
-pub struct StorageIter<'a> {
-    inner: Option<Storage>,
-    count: u32,
-    index: u32,
-    bound: PhantomData<&'a ()>,
-    // pub(crate) value: String,
-}
